@@ -1238,10 +1238,10 @@ class CustomFunction(Tool):
                     tile_size = image_spec.get('generator').get('tile_size',{'width': 512, 'height': 512})
                     tile_overlap = image_spec.get('generator').get('tile_overlap')
 
-                    if current_slide_information.get('type')=='local':
+                    if current_slide_information.get('item_type')=='local_item':
                         tile_iterator = large_image.open(current_slide_information.get('filepath')).tileIterator(tile_size = tile_size, tile_overlap = tile_overlap)
                         kwarg_inputs[all_input_names[all_input_types.index('image')]] = tile_iterator
-                    elif current_slide_innformation.get('type')=='remote':
+                    elif current_slide_innformation.get('item_type')=='remote_item':
                         tile_iterator = DSATileServer.get_tile_iterator(
                             slide_url_dict = current_slide_information,
                             tile_size = tile_size
