@@ -421,10 +421,10 @@ class fusionDB:
         user_id: Union[str,None] = None,
         public: bool = False):
 
-        #print(f'{slide_id=}, {public=}')
-        if item_type is None or item_type=='local':
+        print(f'{slide_id=}, {public=}, {item_type=}, {user_id=}')
+        if item_type=='local_item':
             new_item = self.get_create(
-                table_name = item_type if not item_type is None else 'local',
+                table_name = 'local_item',
                 inst_id = slide_id,
                 kwargs = {
                     'name': slide_name,
@@ -436,9 +436,24 @@ class fusionDB:
                     'public': public, 
                 }
             )
+
+        elif item_type=='remote_item':
+            new_item = self.get_create(
+                table_name = 'remote_item',
+                inst_id = slide_id,
+                kwargs = {
+                    'name': slide_name,
+                    'meta': metadata,
+                    'image_meta': image_metadata,
+                    'ann_meta': annotations_metadata,
+                    'session': vis_session_id,
+                    'public': public, 
+                }
+            )
+
         else:
             new_item = self.get_create(
-                table_name = item_type if not item_type is None else 'remote',
+                table_name = 'item',
                 inst_id = slide_id,
                 kwargs = {
                     'name': slide_name,
@@ -934,6 +949,7 @@ class fusionDB:
             user_access_list = []
 
         print(f'{item_id=}')
+        print(f'{user_token=}')
         print(f'{self.get_ids(table_name = "item",user_token=user_token)=}')
 
         with self.get_db() as session:
