@@ -19,7 +19,7 @@ import dash_mantine_components as dmc
 from dash_extensions.enrich import DashBlueprint, html, Input, Output, State, PrefixIdTransform, MultiplexerTransform
 
 from fusion_tools.visualization.vis_utils import get_pattern_matching_value
-from fusion_tools import DSATool
+from fusion_tools.components.base import DSATool
 from fusion_tools.handler.resource_selector import DSAResourceSelector
 
 from girder_job_sequence import Job, Sequence
@@ -36,6 +36,11 @@ class DSAPluginGroup(DSATool):
     :param DSATool: Class for components that integrate with DSA
     :type DSATool: None
     """
+
+    title = 'DSA Plugin Group'
+    description = ''
+
+
     def __init__(self,
                  handler:None
                 ):
@@ -43,20 +48,10 @@ class DSAPluginGroup(DSATool):
         super().__init__()
         self.handler = handler
 
-        self.embedded_ids = [
-            'dsa-resource-selector'
-        ]
-
-        self.base_id = 'dsa-plugin'
-
-    def __str__(self):
-        return 'DSA Plugin Group'
-
     def load(self, component_prefix: int):
         
         self.component_prefix = component_prefix
 
-        self.title = 'DSA Plugin Group'
         self.blueprint = DashBlueprint(
             transforms=[
                 PrefixIdTransform(prefix=f'{component_prefix}',escape = lambda input_id: self.prefix_escape(input_id)),
@@ -71,14 +66,17 @@ class DSAPluginGroup(DSATool):
             handler = self.handler
         )
         self.resource_selector.load(self.component_prefix)
+        self.resource_selector.gen_layout({})
 
         #TODO: Either add a region selector to DSAResourceSelector or create a separate region selector component
     
     def load_plugin(self, plugin_dict:dict, session_data:dict, component_index:int, sequence=False):
         
+
+        user_external_token = self.get_user_external_token(session_data)
         exe_dict = None
         self.handler.gc.setToken(
-            session_data['current_user']['token']
+            user_external_token
         )
 
         try:
@@ -132,9 +130,9 @@ class DSAPluginGroup(DSATool):
                                 uploaded_item_names = [i['fusion_upload_name'] for i in uploaded_items]
                                 if in_arg['default']['name'] in uploaded_item_names:
                                     matching_item = uploaded_items[uploaded_item_names.index(in_arg['default']['name'])]
-                                    matching_item_info = self.handler.get_item_info(matching_item['itemId'],session_data['current_user']['token'])
+                                    matching_item_info = self.handler.get_item_info(matching_item['itemId'],user_external_token)
                                     if in_arg['default']['type']=='upload_folder':
-                                        folder_info = self.handler.get_folder_info(matching_item_info['folderId'],session_data['current_user']['token'])
+                                        folder_info = self.handler.get_folder_info(matching_item_info['folderId'],user_external_token)
                                         exe_input['default'] = {
                                             'name': folder_info['name'],
                                             '_id': folder_info['_id']
@@ -206,7 +204,7 @@ class DSAPluginGroup(DSATool):
                                     uploaded_parent_names = [i['parentName'] for i in uploaded_annotations]
                                     if in_arg['default']['fileName'] in uploaded_parent_names:
                                         matching_parent = uploaded_annotations[uploaded_parent_names.index(in_arg['default']['name'])]
-                                        annotation_info = self.handler.get_annotation_names(matching_parent['_id'], user_token = session_data['current_user']['token'])
+                                        annotation_info = self.handler.get_annotation_names(matching_parent['_id'], user_token = user_external_token)
 
                                         if 'annotationName' in in_arg['default']:
                                             annotation_names = [i['annotation']['name'] for i in annotation_info]
@@ -235,7 +233,7 @@ class DSAPluginGroup(DSATool):
                                     uploaded_parent_ids = [i['_id'] for i in uploaded_annotations]
                                     if in_arg['default']['fileId'] in uploaded_parent_ids:
                                         matching_parent = uploaded_annotations[uploaded_parent_ids.index(in_arg['default']['fileId'])]
-                                        annotation_info = self.handler.get_annotation_names(matching_parent['_id'], user_token = session_data['current_user']['token'])
+                                        annotation_info = self.handler.get_annotation_names(matching_parent['_id'], user_token = user_external_token)
 
                                         if 'annotationName' in in_arg['default']:
                                             annotation_names = [i['annotation']['name'] for i in annotation_info]
@@ -278,7 +276,7 @@ class DSAPluginGroup(DSATool):
                                     uploaded_item_names = [i['fusion_upload_name'] for i in uploaded_items]
                                     if reference in uploaded_item_names:
                                         matching_item = uploaded_items[uploaded_item_names.index(reference)]
-                                        matching_item_info = self.handler.get_item_info(matching_item['itemId'],session_data['current_user']['token'])
+                                        matching_item_info = self.handler.get_item_info(matching_item['itemId'],user_external_token)
 
                                         item_name = matching_item_info['name']
                                         # Could do something with this, add a _output.{ref_ext} or something if a new extension isn't provided
@@ -301,8 +299,8 @@ class DSAPluginGroup(DSATool):
                                     uploaded_item_names = [i['fusion_upload_name'] for i in uploaded_items]
                                     if reference in uploaded_item_names:
                                         matching_item = uploaded_items[uploaded_item_names.index(reference)]
-                                        matching_item_info = self.handler.get_item_info(matching_item['itemId'],session_data['current_user']['token'])
-                                        folder_info = self.handler.get_folder_info(matching_item_info['folderId'],session_data['current_user']['token'])
+                                        matching_item_info = self.handler.get_item_info(matching_item['itemId'],user_external_token)
+                                        folder_info = self.handler.get_folder_info(matching_item_info['folderId'],user_external_token)
 
                                         exe_input['default']['folderId'] = folder_info['_id']
                                     else:
@@ -595,6 +593,10 @@ class DSAPluginGroup(DSATool):
         :type plugin_groups: Union[list,dict,None], optional
         """
 
+        if type(session_data)==str:
+            session_data = json.loads(session_data)
+        user_external_token = self.get_user_external_token(session_data)
+
         plugin_components = []
         if not plugin_groups is None:
             if type(plugin_groups)==dict:
@@ -739,15 +741,6 @@ class DSAPluginGroup(DSATool):
 
         return layout
 
-    def gen_layout(self, session_data:dict):
-        """Initializing layout of blueprint.
-
-        :param session_data: Dictionary containing information from current session
-        :type session_data: dict
-        """
-
-        self.blueprint.layout = self.update_layout(session_data, use_prefix=False)
-
     def get_callbacks(self):
         """Registering callbacks with blueprint object.
         """
@@ -935,6 +928,9 @@ class DSAPluginGroup(DSATool):
             raise exceptions.PreventUpdate
         
         session_data = json.loads(session_data)
+
+        user_external_token = self.get_user_external_token(session_data)
+
         plugin_info = [json.loads(p_info) for p_info in plugin_info]
         all_plugin_input_info = [json.loads(i_info) for i_info in plugin_input_info]
 
@@ -985,6 +981,8 @@ class DSAPluginGroup(DSATool):
             raise exceptions.PreventUpdate
 
         session_data = json.loads(session_data)
+
+        user_external_token = self.get_user_external_token(session_data)
         # Getting information on this sequence
         sequence_info = json.loads(sequence_info)
         # Getting information on plugins in this sequence
@@ -1090,6 +1088,10 @@ class DSAPluginRunner(DSATool):
     :param DSATool: Class for components that integrate with DSA.
     :type DSATool: None
     """
+
+    title = 'DSA Plugin Runner'
+    description = 'Select a plugin to run on the cloud!'
+
     def __init__(self,
                  handler: None
                  ):
@@ -1097,18 +1099,10 @@ class DSAPluginRunner(DSATool):
         super().__init__()
         self.handler = handler
 
-        self.embedded_ids = [
-            'dsa-resource-selector',
-            'dsa-plugin'
-        ]
-
-        self.base_id = 'dsa-plugin-runner'
-
     def load(self, component_prefix: int):
         
         self.component_prefix = component_prefix
 
-        self.title = 'DSA Plugin Runner'
         self.blueprint = DashBlueprint(
             transforms=[
                 PrefixIdTransform(prefix=f'{component_prefix}', escape = lambda input_id: self.prefix_escape(input_id)),
@@ -1126,7 +1120,11 @@ class DSAPluginRunner(DSATool):
     
     def update_layout(self, session_data:dict, use_prefix: bool):
         
-        plugin_list = self.handler.list_plugins(user_token = session_data['current_user']['token'])
+        if type(session_data)==str:
+            session_data = json.loads(session_data)
+
+        user_external_token = self.get_user_external_token(session_data)
+        plugin_list = self.handler.list_plugins(user_token = user_external_token)
         docker_list = sorted(list(set([i['image'] for i in plugin_list])))
 
         if not use_prefix:
@@ -1136,11 +1134,11 @@ class DSAPluginRunner(DSATool):
             dbc.Card([
                 dbc.CardBody([
                     dbc.Row(
-                        html.H3('DSA Plugin Runner')
+                        html.H3(self.title)
                     ),
                     html.Hr(),
                     dbc.Row(
-                        'Select a plugin to run on the cloud!'
+                        self.description
                     ),
                     html.Hr(),
                     dbc.Row([
@@ -1183,10 +1181,6 @@ class DSAPluginRunner(DSATool):
 
         return layout
 
-    def gen_layout(self, session_data:dict):
-        
-        self.blueprint.layout = self.update_layout(session_data, use_prefix=False)
-
     def get_callbacks(self):
 
         # Callback to get all the CLIs for a selected Docker image
@@ -1225,7 +1219,10 @@ class DSAPluginRunner(DSATool):
         
         docker_select = get_pattern_matching_value(docker_select)
         session_data = json.loads(session_data)
-        plugin_list = self.handler.list_plugins(user_token=session_data['current_user']['token'])
+
+        user_external_token = self.get_user_external_token(session_data)
+
+        plugin_list = self.handler.list_plugins(user_token=user_external_token)
         included_cli = sorted([i['name'] for i in plugin_list if i['image']==docker_select])
 
         return [included_cli]
@@ -1258,6 +1255,10 @@ class DSAPluginProgress(DSATool):
     :param Tool: General class for components that perform visualization and analysis of data.
     :type Tool: None
     """
+
+    title = 'DSA Plugin Progress'
+    description = 'Monitor the progress of currently running plugins.'
+
     def __init__(self,
                  handler):
         
@@ -1282,30 +1283,15 @@ class DSAPluginProgress(DSATool):
     
         self.modal_className = 'mw-100 p-5'
 
-    def __str__(self):
-        return 'DSA Plugin Progress'
-
-    def load(self,component_prefix:int):
-        
-        self.component_prefix = component_prefix
-
-        self.title = 'DSA Plugin Progress'
-
-        self.blueprint = DashBlueprint(
-            transforms=[
-                PrefixIdTransform(prefix=f'{component_prefix}'),
-                MultiplexerTransform()
-            ]
-        )
-
-        self.get_callbacks()
-
     def generate_plugin_table(self, session_data:dict, offset:int, limit: int, next_clicks:int, prev_clicks:int, use_prefix:bool):
+        
+        user_external_token = self.get_user_external_token(session_data)
+        user_external_id = self.get_user_external_id(session_data)
 
         # Getting all jobs for this user:
         user_jobs = self.handler.get_user_jobs(
-            user_id = session_data['current_user']['_id'],
-            user_token = session_data['current_user']['token'],
+            user_id = user_external_id,
+            user_token = user_external_token,
             offset = offset,
             limit = limit
         )
@@ -1413,7 +1399,7 @@ class DSAPluginProgress(DSATool):
 
     def update_layout(self, session_data:dict, use_prefix:bool):
         
-        if 'current_user' in session_data:
+        if 'user' in session_data:
             running_plugins = self.generate_plugin_table(session_data, 0, 5, 0, 0, False)
             running_plugins = dmc.Table(
                 running_plugins,
@@ -1430,11 +1416,11 @@ class DSAPluginProgress(DSATool):
             dbc.Card(
                 dbc.CardBody([
                     dbc.Row(
-                        html.H3('DSA Plugin Progress')
+                        html.H3(self.title)
                     ),
                     html.Hr(),
                     dbc.Row(
-                        'Monitor the progress of currently running plugins.'
+                        self.description
                     ),
                     dbc.Row(
                         html.Div(
@@ -1457,10 +1443,6 @@ class DSAPluginProgress(DSATool):
 
         return layout
 
-    def gen_layout(self,session_data:Union[dict,None]):
-        
-        self.blueprint.layout = self.update_layout(session_data=session_data,use_prefix=False)
-
     def get_callbacks(self):
 
         # Callback for loading next/prev jobs
@@ -1511,13 +1493,13 @@ class DSAPluginProgress(DSATool):
        
         session_data = json.loads(session_data)
         new_table_content = self.generate_plugin_table(
-                                session_data = session_data,
-                                offset = offset,
-                                limit = 5,
-                                next_clicks = next_clicked,
-                                prev_clicks = prev_clicked,
-                                use_prefix = True
-                            )
+            session_data = session_data,
+            offset = offset,
+            limit = 5,
+            next_clicks = next_clicked,
+            prev_clicks = prev_clicked,
+            use_prefix = True
+        )
 
 
         return [new_table_content]
@@ -1529,13 +1511,15 @@ class DSAPluginProgress(DSATool):
         
         session_data = json.loads(session_data)
 
+        user_external_token = self.get_user_external_token(session_data)
+
         if 'dsa-plugin-progress-get-logs' in ctx.triggered_id['type']:
             row_clicked = ctx.triggered_id['index']
             job_id = table_rows[row_clicked][5]['props']['children']
 
             job_logs = self.handler.get_specific_job(
                 job_id = job_id,
-                user_token = session_data['current_user']['token']
+                user_token = user_external_token
             )
 
             job_logs_div = html.Div(
@@ -1552,7 +1536,7 @@ class DSAPluginProgress(DSATool):
 
             cancel_response = self.handler.cancel_job(
                 job_id = job_id,
-                user_token = session_data['current_user']['token']
+                user_token = user_external_token
             )
 
             job_logs_div = html.Div(
